@@ -3,6 +3,7 @@ use strict;
 our $VERSION = '0.11';
 
 use base qw( SVK::Command );
+use SVK::I18N;
 
 sub parse_arg {
     my ($self, @arg) = @_;
@@ -10,20 +11,15 @@ sub parse_arg {
     return map {$self->arg_copath ($_)} @arg;
 }
 
-sub lock {
-    my $self = shift;
-    $self->lock_target ($_) for @_;
-}
-
 sub run {
     my ($self, @arg) = @_;
     for (@arg) {
 	if ($self->{xd}{checkout}->get ($_->{copath})->{lock}) {
-	    print "Cleanup stalled lock at $_->{copath}\n";
+	    print loc("Cleaned up stalled lock on %1.\n", $_->{copath});
 	    $self->{xd}{checkout}->store ($_->{copath}, {lock => undef});
 	}
 	else {
-	    print "$_->{copath} not locked\n";
+	    print loc("Path %1 was not locked.\n", $_->{copath});
 	}
     }
     return;
@@ -34,12 +30,16 @@ sub run {
 
 =head1 NAME
 
-cleanup - Cleanup stalled locks.
+SVK::Command::Cleanup - Remove stalled locks
 
 =head1 SYNOPSIS
 
     cleanup [PATH...]
 
+=head1 OPTIONS
+
+   None
+
 =head1 AUTHORS
 
 Chia-liang Kao E<lt>clkao@clkao.orgE<gt>
