@@ -3,6 +3,7 @@ use strict;
 our $VERSION = '0.11';
 
 use base qw( SVK::Command::Commit );
+use SVK::I18N;
 
 sub parse_arg {
     my ($self, @arg) = @_;
@@ -13,7 +14,7 @@ sub lock { $_[0]->lock_none }
 
 sub run {
     my ($self, $target, $source) = @_;
-    die "require SVN::Mirror" unless $self->svn_mirror;
+    die loc("cannot load SVN::Mirror") unless $self->svn_mirror;
 
     my $m = SVN::Mirror->new (target_path => $target->{path}, target => $target->{repospath},
 			      repos => $target->{repos},
@@ -27,12 +28,19 @@ sub run {
 
 =head1 NAME
 
-mirror - Initialize a mirrored depotpath.
+SVK::Command::Mirror - Initialize a mirrored depotpath
 
 =head1 SYNOPSIS
 
     mirror DEPOTPATH SOURCEURL
 
+=head1 OPTIONS
+
+  -m [--message] arg:	Needs description
+  -C [--check-only]:	Needs description
+  -s [--sign]:	Needs description
+  --force:	Needs description
+
 =head1 AUTHORS
 
 Chia-liang Kao E<lt>clkao@clkao.orgE<gt>
