@@ -15,7 +15,7 @@ sub run {
 
 =head1 NAME
 
-smerge - Automatic merge all changes between branches.
+SVK::Command::Smerge - Automatic merge all changes between branches
 
 =head1 SYNOPSIS
 
@@ -24,10 +24,14 @@ smerge - Automatic merge all changes between branches.
 
 =head1 OPTIONS
 
-    -m message:             commit message
+    -m [--message] message:             commit message
     -C [--check-only]:      don't perform actual writes
     -l [--log]:             brings the logs of merged revs to the message buffer
     --no-ticket:            don't associate the ticket tracking merge history
+    -r [--revision] arg:    Needs description
+    -a [--auto]:	    Needs description
+    --force:		    Needs description
+    -s [--sign]:	    Needs description
 
 =head1 AUTHORS
 
