@@ -4,6 +4,7 @@ our $VERSION = '0.11';
 
 use base qw( SVK::Command::Update );
 use SVK::XD;
+use SVK::I18N;
 use File::Spec;
 
 sub parse_arg {
@@ -18,14 +19,15 @@ sub lock { $_[0]->lock_target ($_[2]) }
 sub run {
     my ($self, $target, $depotpath) = @_;
 
-    die "different depot" unless $target->{repospath} eq $depotpath->{repospath};
+    die loc("different depot") unless $target->{repospath} eq $depotpath->{repospath};
 
     my ($entry, @where) = $self->{xd}{checkout}->get ($depotpath->{copath});
 
-    die "can only switch checkout root" unless $where[-1] eq $depotpath->{copath};
+    die loc("can only switch checkout root") unless $where[0] eq $depotpath->{copath};
 
     $self->{rev} = $target->{repos}->fs->youngest_rev unless defined $self->{rev};
 
+    # XXX: check relation between target_path and path
     $depotpath->{target_path} = $target->{path};
     $self->SUPER::run ($depotpath);
 
@@ -37,7 +39,7 @@ sub run {
 
 =head1 NAME
 
-switch - Switch to another branch and keep local modifications.
+SVK::Command::Switch - Switch to another branch and keep local modifications
 
 =head1 SYNOPSIS
 
@@ -47,6 +49,10 @@ switch - Switch to another branch and keep local modifications.
 
     -r [--revision]:      revision
 
+=head1 OPTIONS
+
+  -r [--revision] arg:	Needs description
+
 =head1 AUTHORS
 
 Chia-liang Kao E<lt>clkao@clkao.orgE<gt>
