@@ -1,12 +1,18 @@
 package SVK::Util;
+use strict;
 require Exporter;
-@ISA       = qw(Exporter);
-@EXPORT_OK = qw(md5 get_buffer_from_editor slurp_fh get_anchor get_prompt);
-$VERSION   = '0.09';
+our @ISA       = qw(Exporter);
+our @EXPORT_OK = qw(md5 get_buffer_from_editor slurp_fh get_anchor get_prompt
+		    find_svm_source resolve_svm_source svn_mirror);
+our $VERSION   = '0.09';
 
+use SVK::I18N;
 use Digest::MD5 qw(md5_hex);
 use File::Temp;
 use Term::ReadLine;
+my $svn_mirror = eval 'require SVN::Mirror; 1' ? 1 : 0;
+
+sub svn_mirror { $svn_mirror }
 
 my $tr;
 sub get_prompt {
@@ -47,15 +53,15 @@ sub get_buffer_from_editor {
 	my $editor =	defined($ENV{SVN_EDITOR}) ? $ENV{SVN_EDITOR}
 	   		: defined($ENV{EDITOR}) ? $ENV{EDITOR}
 			: "vi"; # fall back to something
-	print "waiting for editor...\n";
-	system ($editor, $file) and die "Aborted";
+	print loc("Waiting for editor...\n");
+	system ($editor, $file) and die loc("Aborted.\n");
 	last if (stat($file))[9] > $mtime;
 	my $ans = get_prompt(
-	    "$what not modified: a)bort, e)dit, c)ommit?",
+	    loc("%1 not modified: a)bort, e)dit, c)ommit?", $what),
 	    qr/^[aec]/,
 	);
 	last if $ans =~ /^c/;
-	die "aborted.\n" if $ans =~ /^a/;
+	die loc("Aborted.\n") if $ans =~ /^a/;
     }
 
     open $fh, $file;
@@ -91,5 +97,39 @@ sub get_anchor {
     } @_;
 }
 
+sub find_svm_source {
+    my ($repos, $path) = @_;
+    my ($uuid, $rev, $m, $mpath);
+    my $mirrored;
+    my $fs = $repos->fs;
+    my $root = $fs->revision_root ($fs->youngest_rev);
+
+    if (svn_mirror) {
+	($m, $mpath) = SVN::Mirror::is_mirrored ($repos, $path);
+    }
+
+    if ($m) {
+	$path =~ s/\Q$mpath\E$//;
+	$uuid = $root->node_prop ($path, 'svm:uuid');
+	$path = $m->{source}.$mpath;
+	$path =~ s/^\Q$m->{source_root}\E//;
+	$rev = $m->{fromrev};
+    }
+    else {
+	($rev, $uuid) = ($fs->youngest_rev, $fs->get_uuid);
+    }
+
+    return ($uuid, $path, $rev);
+}
+
+sub resolve_svm_source {
+    my ($repos, $uuid, $path) = @_;
+    my $myuuid = $repos->fs->get_uuid;
+    return ($path) if ($uuid eq $myuuid);
+    return unless svn_mirror;
+    my ($m, $mpath) = SVN::Mirror::has_local ($repos, "$uuid:$path");
+    return unless $m;
+    return ("$m->{target_path}$mpath", $m);
+}
 
 1;
